@@ -7,24 +7,30 @@
 #' @inheritParams hdi
 #'
 #' @details
-#' \strong{What is the \emph{pd}?}
-#' \cr \cr
+#' \subsection{What is the \emph{pd}?}{
 #' The Probability of Direction (pd) is an index of effect existence, ranging from 50\% to 100\%, representing the certainty with which an effect goes in a particular direction (\emph{i.e.}, is positive or negative). Beyond its simplicity of interpretation, understanding and computation, this index also presents other interesting properties:
 #' \itemize{
 #'   \item It is independent from the model: It is solely based on the posterior distributions and does not require any additional information from the data or the model.
 #'   \item It is robust to the scale of both the response variable and the predictors.
 #'   \item It is strongly correlated with the frequentist p-value, and can thus be used to draw parallels and give some reference to readers non-familiar with Bayesian statistics.
 #' }
-#' \strong{Relationship with the p-value}
-#' \cr \cr
+#' }
+#' \subsection{Relationship with the p-value}{
 #' In most cases, it seems that the \emph{pd} has a direct correspondance with the frequentist one-sided \emph{p}-value through the formula \ifelse{html}{\out{p<sub>one&nbsp;sided</sub>&nbsp;=&nbsp;1&nbsp;-&nbsp;<sup>p(<em>d</em>)</sup>/<sub>100</sub>}}{\eqn{p_{one sided}=1-\frac{p_{d}}{100}}} and to the two-sided p-value (the most commonly reported one) through the formula \ifelse{html}{\out{p<sub>two&nbsp;sided</sub>&nbsp;=&nbsp;2&nbsp;*&nbsp;(1&nbsp;-&nbsp;<sup>p(<em>d</em>)</sup>/<sub>100</sub>)}}{\eqn{p_{two sided}=2*(1-\frac{p_{d}}{100})}}. Thus, a two-sided p-value of respectively \code{.1}, \code{.05}, \code{.01} and \code{.001} would correspond approximately to a \emph{pd} of 95\%, 97.5\%, 99.5\% and 99.95\%.
-#' \cr \cr
-#' \strong{Methods of computation}
-#' \cr \cr
+#' }
+#' \subsection{Methods of computation}{
 #'  The most simple and direct way to compute the \emph{pd} is to 1) look at the median's sign, 2) select the portion of the posterior of the same sign and 3) compute the percentage that this portion represents. This "simple" method is the most straigtfoward, but its precision is directly tied to the number of posterior draws. The second approach relies on \link[=estimate_density]{density estimation}. It starts by estimating the density function (for which many methods are available), and then computing the \link[=area_under_curve]{area under the curve} (AUC) of the density curve on the other side of 0.
+#' }
+#' \subsection{Strengths and Limitations}{
+#' \strong{Strengths:} Straightforward computation and interpretation. Objective property of the posterior distribution. 1:1 correspondence with the frequentist p-value.
+#' \cr \cr
+#' \strong{Limitations:} Limited information favoring the null hypothesis.
+#' }
 #'
 #' @return Values between 0.5 and 1 corresponding to the probability of direction (pd).
 #'
+#' @references Makowski D, Ben-Shachar MS, Chen SHA, Lüdecke D (2019) Indices of Effect Existence and Significance in the Bayesian Framework. Frontiers in Psychology 2019;10:2767. \doi{10.3389/fpsyg.2019.02767}
+#'
 #' @examples
 #' library(bayestestR)
 #'
@@ -69,7 +75,6 @@
 #' p_direction(bf)
 #' p_direction(bf, method = "kernel")
 #' }
-#'
 #' @export
 p_direction <- function(x, ...) {
   UseMethod("p_direction")
@@ -134,7 +139,7 @@ p_direction.data.frame <- function(x, method = "direct", ...) {
     stringsAsFactors = FALSE
   )
 
-  attr(out, "object_name") <- deparse(substitute(x), width.cutoff = 500)
+  attr(out, "object_name") <- .safe_deparse(substitute(x))
   class(out) <- unique(c("p_direction", "see_p_direction", class(out)))
 
   out
@@ -145,7 +150,15 @@ p_direction.data.frame <- function(x, method = "direct", ...) {
 #' @export
 p_direction.MCMCglmm <- function(x, method = "direct", ...) {
   nF <- x$Fixed$nfl
-  p_direction(as.data.frame(x$Sol[, 1:nF, drop = FALSE]), method = method, ...)
+  out <- p_direction(as.data.frame(x$Sol[, 1:nF, drop = FALSE]), method = method, ...)
+  attr(out, "object_name") <- .safe_deparse(substitute(x))
+  out
+}
+
+
+#' @export
+p_direction.mcmc <- function(x, method = "direct", ...) {
+  p_direction(as.data.frame(x), method = method, ...)
 }
 
 
@@ -164,9 +177,7 @@ p_direction.emmGrid <- function(x, method = "direct", ...) {
 #' @importFrom insight get_parameters
 #' @keywords internal
 .p_direction_models <- function(x, effects, component, parameters, method = "direct", ...) {
-  out <- p_direction(insight::get_parameters(x, effects = effects, component = component, parameters = parameters), method = method, ...)
-
-  out
+  p_direction(insight::get_parameters(x, effects = effects, component = component, parameters = parameters), method = method, ...)
 }
 
 
@@ -214,7 +225,7 @@ p_direction.stanreg <- function(x, effects = c("fixed", "random", "all"), parame
   )
 
   class(out) <- unique(c("p_direction", "see_p_direction", class(out)))
-  attr(out, "object_name") <- deparse(substitute(x), width.cutoff = 500)
+  attr(out, "object_name") <- .safe_deparse(substitute(x))
   out
 }
 
@@ -231,7 +242,7 @@ p_direction.brmsfit <- function(x, effects = c("fixed", "random", "all"), compon
   )
 
   class(out) <- unique(c("p_direction", "see_p_direction", class(out)))
-  attr(out, "object_name") <- deparse(substitute(x), width.cutoff = 500)
+  attr(out, "object_name") <- .safe_deparse(substitute(x))
   out
 }
 
@@ -240,7 +251,7 @@ p_direction.brmsfit <- function(x, effects = c("fixed", "random", "all"), compon
 #' @export
 p_direction.BFBayesFactor <- function(x, method = "direct", ...) {
   out <- p_direction(insight::get_parameters(x), method = method, ...)
-  attr(out, "object_name") <- deparse(substitute(x), width.cutoff = 500)
+  attr(out, "object_name") <- .safe_deparse(substitute(x))
   out
 }
 
