@@ -1,6 +1,6 @@
 #' Region of Practical Equivalence (ROPE)
 #'
-#' Compute the proportion (in percentage) of the HDI (default to the 90\% HDI) of a posterior distribution that lies within a region of practical equivalence.
+#' Compute the proportion of the HDI (default to the 89\% HDI) of a posterior distribution that lies within a region of practical equivalence.
 #'
 #' @param x Vector representing a posterior distribution. Can also be a \code{stanreg} or \code{brmsfit} model.
 #' @param range ROPE's lower and higher bounds. Should be a vector of length two (e.g., \code{c(-0.1, 0.1)}) or \code{"default"}. If \code{"default"}, the range is set to \code{c(-0.1, 0.1)} if input is a vector, and based on \code{\link[=rope_range]{rope_range()}} if a Bayesian model is provided.
@@ -9,7 +9,9 @@
 #'
 #' @inheritParams hdi
 #'
-#' @details Statistically, the probability of a posterior distribution of being
+#' @details
+#' \subsection{ROPE}{
+#'   Statistically, the probability of a posterior distribution of being
 #'   different from 0 does not make much sense (the probability of a single value
 #'   null hypothesis in a continuous distribution is 0). Therefore, the idea
 #'   underlining ROPE is to let the user define an area around the null value
@@ -27,9 +29,8 @@
 #'   (or 89\%, considered more stable) \link[=hdi]{HDI} that falls within the
 #'   ROPE as an index for "null-hypothesis" testing (as understood under the
 #'   Bayesian framework, see \code{\link[=equivalence_test]{equivalence_test()}}).
-#'   \cr \cr
-#'   \strong{ Sensitivity to parameter's scale}
-#'   \cr \cr
+#' }
+#' \subsection{Sensitivity to parameter's scale}{
 #'   It is important to consider the unit (i.e., the scale) of the predictors
 #'   when using an index based on the ROPE, as the correct interpretation of the
 #'   ROPE as representing a region of practical equivalence to zero is dependent
@@ -37,9 +38,8 @@
 #'   the unit of its parameter. In other words, as the ROPE represents a fixed
 #'   portion of the response's scale, its proximity with a coefficient depends
 #'   on the scale of the coefficient itself.
-#'   \cr \cr
-#'   \strong{Multicollinearity: Non-independent covariates}
-#'   \cr \cr
+#' }
+#' \subsection{Multicollinearity: Non-independent covariates}{
 #'   When parameters show strong correlations, i.e. when covariates are not
 #'   independent, the joint parameter distributions may shift towards or
 #'   away from the ROPE. Collinearity invalidates ROPE and hypothesis
@@ -55,6 +55,12 @@
 #'   a first step to check the assumptions of this hypothesis testing is to look
 #'   at different pair plots. An even more sophisticated check is the projection
 #'   predictive variable selection (\cite{Piironen and Vehtari 2017}).
+#' }
+#' \subsection{Strengths and Limitations}{
+#'   \strong{Strengths:} Provides information related to the practical relevance of the effects.
+#'   \cr \cr
+#'   \strong{Limitations:} A ROPE range needs to be arbitrarily defined. Sensitive to the scale (the unit) of the predictors. Not sensitive to highly significant effects.
+#' }
 #'
 #' @references \itemize{
 #' \item Cohen, J. (1988). Statistical power analysis for the behavioural sciences.
@@ -62,6 +68,7 @@
 #' \item Kruschke, J. K. (2011). Bayesian assessment of null values via parameter estimation and model comparison. Perspectives on Psychological Science, 6(3), 299-312. \doi{10.1177/1745691611406925}.
 #' \item Kruschke, J. K. (2014). Doing Bayesian data analysis: A tutorial with R, JAGS, and Stan. Academic Press. \doi{10.1177/2515245918771304}.
 #' \item Kruschke, J. K. (2018). Rejecting or accepting parameter values in Bayesian estimation. Advances in Methods and Practices in Psychological Science, 1(2), 270-280. \doi{10.1177/2515245918771304}.
+#' \item Makowski D, Ben-Shachar MS, Chen SHA, Lüdecke D (2019) Indices of Effect Existence and Significance in the Bayesian Framework. Frontiers in Psychology 2019;10:2767. \doi{10.3389/fpsyg.2019.02767}
 #' \item Piironen, J., & Vehtari, A. (2017). Comparison of Bayesian predictive methods for model selection. Statistics and Computing, 27(3), 711–735. \doi{10.1007/s11222-016-9649-y}
 #' }
 #'
@@ -91,7 +98,6 @@
 #' rope(bf)
 #' rope(bf, ci = c(.90, .95))
 #' }
-#'
 #' @importFrom insight get_parameters is_multivariate
 #' @export
 rope <- function(x, ...) {
@@ -173,13 +179,13 @@ rope.data.frame <- function(x, range = "default", ci = .89, ci_method = "HDI", v
 
 #' @rdname rope
 #' @export
-rope.emmGrid <- function(x, range = "default", ci = .89, verbose = TRUE, ...) {
+rope.emmGrid <- function(x, range = "default", ci = .89, ci_method = "HDI", verbose = TRUE, ...) {
   if (!requireNamespace("emmeans")) {
     stop("Package 'emmeans' required for this function to work. Please install it by running `install.packages('emmeans')`.")
   }
   xdf <- as.data.frame(as.matrix(emmeans::as.mcmc.emmGrid(x, names = FALSE)))
 
-  dat <- rope(xdf, range = range, ci = ci, verbose = verbose, ...)
+  dat <- rope(xdf, range = range, ci = ci, ci_method = ci_method, verbose = verbose, ...)
   attr(dat, "object_name") <- .safe_deparse(substitute(x))
   dat
 }
@@ -188,21 +194,34 @@ rope.emmGrid <- function(x, range = "default", ci = .89, verbose = TRUE, ...) {
 
 #' @rdname rope
 #' @export
-rope.BFBayesFactor <- function(x, range = "default", ci = .89, verbose = TRUE, ...) {
-  out <- rope(insight::get_parameters(x), range = range, ci = ci, verbose = verbose, ...)
+rope.BFBayesFactor <- function(x, range = "default", ci = .89, ci_method = "HDI", verbose = TRUE, ...) {
+  out <- rope(insight::get_parameters(x), range = range, ci = ci, ci_method = ci_method, verbose = verbose, ...)
+  attr(out, "object_name") <- .safe_deparse(substitute(x))
   out
 }
 
 
 #' @rdname rope
 #' @export
-rope.MCMCglmm <- function(x, range = "default", ci = .89, verbose = TRUE, ...) {
+rope.MCMCglmm <- function(x, range = "default", ci = .89, ci_method = "HDI", verbose = TRUE, ...) {
   nF <- x$Fixed$nfl
-  out <- rope(as.data.frame(x$Sol[, 1:nF, drop = FALSE]), range = range, ci = ci, verbose = verbose, ...)
+  out <- rope(as.data.frame(x$Sol[, 1:nF, drop = FALSE]), range = range, ci = ci, ci_method = ci_method, verbose = verbose, ...)
+  attr(out, "object_name") <- .safe_deparse(substitute(x))
   out
 }
 
 
+#' @export
+rope.mcmc <- function(x, range = "default", ci = .89, ci_method = "HDI", verbose = TRUE, ...) {
+  out <- rope(as.data.frame(x), range = range, ci = ci, ci_method = ci_method, verbose = verbose, ...)
+  attr(out, "object_name") <- NULL
+  attr(out, "data") <- .safe_deparse(substitute(x))
+  out
+}
+
+
+
+
 #' @keywords internal
 .rope <- function(x, range = c(-0.1, 0.1), ci = .89, ci_method = "HDI", verbose = TRUE) {
   ci_bounds <- ci(x, ci = ci, method = ci_method, verbose = verbose)
