@@ -6,40 +6,46 @@ test_that("describe_posterior", {
   # Numeric
   x <- distribution_normal(1000)
   rez <- testthat::expect_warning(describe_posterior(x, centrality = "all", dispersion = TRUE, test = "all"))
-  testthat::expect_equal(dim(rez), c(1, 17))
+  testthat::expect_equal(dim(rez), c(1, 19))
+  testthat::expect_equal(colnames(rez), c("Parameter", "Median", "MAD", "Mean", "SD", "MAP", "CI", "CI_low",
+                                          "CI_high", "p_map", "pd", "p_ROPE", "ps", "ROPE_CI", "ROPE_low",
+                                          "ROPE_high", "ROPE_Percentage", "ROPE_Equivalence", "BF"))
   rez <- testthat::expect_warning(describe_posterior(x, centrality = "all", dispersion = TRUE, test = "all", ci = c(0.8, 0.9)))
-  testthat::expect_equal(dim(rez), c(2, 17))
+  testthat::expect_equal(dim(rez), c(2, 19))
   rez <- describe_posterior(x, centrality = NULL, dispersion = TRUE, test = NULL, ci_method = "quantile")
   testthat::expect_equal(dim(rez), c(1, 4))
 
   # Dataframes
   x <- data.frame(replicate(4, rnorm(100)))
   rez <- testthat::expect_warning(describe_posterior(x, centrality = "all", dispersion = TRUE, test = "all"))
-  testthat::expect_equal(dim(rez), c(4, 17))
+  testthat::expect_equal(dim(rez), c(4, 19))
   rez <- testthat::expect_warning(describe_posterior(x, centrality = "all", dispersion = TRUE, test = "all", ci = c(0.8, 0.9)))
-  testthat::expect_equal(dim(rez), c(8, 17))
+  testthat::expect_equal(dim(rez), c(8, 19))
   rez <- describe_posterior(x, centrality = NULL, dispersion = TRUE, test = NULL, ci_method = "quantile")
   testthat::expect_equal(dim(rez), c(4, 4))
-  # rez <- testthat::expect_warning(describe_posterior(x, ci = c(0.8, 0.9)))
-  # testthat::expect_equal(dim(rez), c(8, 17))
 
   # Rstanarm
   library(rstanarm)
   x <- insight::download_model("stanreg_lm_1")
   rez <- describe_posterior(x, centrality = "all", dispersion = TRUE, test = "all")
-  testthat::expect_equal(dim(rez), c(2, 19))
+  testthat::expect_equal(dim(rez), c(2, 21))
+  testthat::expect_equal(colnames(rez), c("Parameter", "Median", "MAD", "Mean", "SD", "MAP", "CI", "CI_low",
+                                          "CI_high", "p_MAP", "pd", "p_ROPE", "ps", "ROPE_CI", "ROPE_low",
+                                          "ROPE_high", "ROPE_Percentage", "ROPE_Equivalence", "BF", "Rhat",
+                                          "ESS"))
   rez <- describe_posterior(x, centrality = "all", dispersion = TRUE, test = "all", ci = c(0.8, 0.9))
-  testthat::expect_equal(dim(rez), c(4, 19))
+  testthat::expect_equal(dim(rez), c(4, 21))
   rez <- describe_posterior(x, centrality = NULL, dispersion = TRUE, test = NULL, ci_method = "quantile", diagnostic = NULL, priors = FALSE)
   testthat::expect_equal(dim(rez), c(2, 4))
 
   # Brms
   library(brms)
   x <- insight::download_model("brms_mixed_1")
-  # rez <- describe_posterior(x, centrality = "all", dispersion = TRUE, test = "all")  # doenst work because of BFs
-  # testthat::expect_equal(dim(rez), c(4, 16))
   rez <- describe_posterior(x, centrality = "all", dispersion = TRUE, ci = c(0.8, 0.9))
   testthat::expect_equal(dim(rez), c(4, 16))
+  testthat::expect_equal(colnames(rez), c("Parameter", "Median", "MAD", "Mean", "SD", "MAP", "CI", "CI_low",
+                                          "CI_high", "pd", "ROPE_CI", "ROPE_low", "ROPE_high", "ROPE_Percentage",
+                                          "ESS", "Rhat"))
   rez <- describe_posterior(x, centrality = NULL, dispersion = TRUE, test = NULL, ci_method = "quantile", diagnostic = NULL)
   testthat::expect_equal(dim(rez), c(2, 4))
 
@@ -79,3 +85,25 @@ if (require("insight")) {
     )
   })
 }
+
+
+test_that("describe_posterior w/ BF+SI", {
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
+
+  x <- insight::download_model("stanreg_lm_1")
+  set.seed(555)
+  rez <- describe_posterior(x, ci_method = "SI", test = "bf")
+
+
+  # test si
+  set.seed(555)
+  rez_si <- si(x)
+  testthat::expect_equal(rez$CI_low, rez_si$CI_low, tolerance = 0.1)
+  testthat::expect_equal(rez$CI_high, rez_si$CI_high, tolerance = 0.1)
+
+  # test BF
+  set.seed(555)
+  rez_bf <- bayesfactor_parameters(x)
+  testthat::expect_equal(rez$BF, rez_bf$BF, tolerance = 0.1)
+})
\ No newline at end of file
