@@ -3,8 +3,8 @@ context("rope")
 test_that("rope", {
   testthat::expect_equal(as.numeric(rope(distribution_normal(1000, 0, 1))), 0.0898, tolerance = 0.01)
   testthat::expect_equal(equivalence_test(distribution_normal(1000, 0, 1))$ROPE_Equivalence, "Undecided")
-  testthat::expect_equal(length(capture.output(print(equivalence_test(distribution_normal(1000))))), 7)
-  testthat::expect_equal(length(capture.output(print(equivalence_test(distribution_normal(1000), ci = c(0.8, 0.9))))), 10)
+  testthat::expect_equal(length(capture.output(print(equivalence_test(distribution_normal(1000))))), 9)
+  testthat::expect_equal(length(capture.output(print(equivalence_test(distribution_normal(1000), ci = c(0.8, 0.9))))), 14)
 
   testthat::expect_equal(as.numeric(rope(distribution_normal(1000, 2, 0.01))), 0, tolerance = 0.01)
   testthat::expect_equal(equivalence_test(distribution_normal(1000, 2, 0.01))$ROPE_Equivalence, "Rejected")
@@ -14,7 +14,7 @@ test_that("rope", {
 
   testthat::expect_equal(equivalence_test(distribution_normal(1000, 0, 0.001), ci = 1)$ROPE_Equivalence, "Accepted")
 
-  print(rope(rnorm(1000, mean = 0, sd = 3), ci = .5))
+  # print(rope(rnorm(1000, mean = 0, sd = 3), ci = .5))
   testthat::expect_equal(rope(rnorm(1000, mean = 0, sd = 3), ci = c(.1, .5, .9))$CI, c(10, 50, 90))
 
   x <- equivalence_test(distribution_normal(1000, 1, 1), ci = c(.50, .99))
